@@ -1,30 +1,28 @@
 """
 This script is used to analyse the results of the simulations for substrate with chiral centers
 """
-from glob import glob
 import numpy as np
 import pandas as pd
 import argparse
-from os.path import basename, dirname, commonprefix
-import os
 import sys
 import re
 import matplotlib.pyplot as plt
-from .helper import commonlist, find_log, map_atom_string
+from .helper import match_dist, check_completed_log
 from .analysis import all_profiles
 import mdtraj as md
 import Bio.PDB
 from multiprocessing import Pool
 from functools import partial
+from pathlib import Path
 plt.switch_backend('agg')
 
 
 def parse_args():
     parser = argparse.ArgumentParser(description="Analyse the different PELE simulations and create plots")
     # main required arguments
-    parser.add_argument("--inp", required=True,
-                        help="Include the path of the completed_simulations.log created after satumut")
-    parser.add_argument("-ip","--initial_pdb", required=True,
+    parser.add_argument("-f", "--simulation_folder", required=True,
+                        help="Include the path to the folder created during the simulation")
+    parser.add_argument("-ip", "--initial_pdb", required=True,
                         help="Include the path of input pdb of the simulation")
     parser.add_argument("--dpi", required=False, default=800, type=int,
                         help="Set the quality of the plots")
@@ -47,7 +45,7 @@ def parse_args():
                         help="The path to the folder where the reports from wild type simulation are")
     args = parser.parse_args()
 
-    return [args.inp, args.dpi, args.traj, args.plot, args.cpus,
+    return [args.simulation_folder, args.dpi, args.traj, args.plot, args.cpus,
             args.catalytic_distance, args.xtc, args.extract, args.dihedral_atoms, args.energy_threshold,
             args.initial_pdb, args.profile_with, args.wild]
 
@@ -72,15 +70,15 @@ def dihedral(trajectory, select, topology=None):
     """
     if ".xtc" in trajectory:
         traj = md.load_xtc(trajectory, topology)
-        num = int(basename(trajectory).replace(".xtc", "").split("_")[1])
+        num = int(Path(trajectory).name.replace(".xtc", "").split("_")[1])
     else:
         traj = md.load_pdb(trajectory)
-        num = int(basename(trajectory).replace(".pdb", "").split("_")[1])
+        num = int(Path(trajectory).name.replace(".pdb", "").split("_")[1])
     traj = traj[int(len(traj)*0.10):]
-    Atom_pair_1 = int(traj.topology.select("resSeq {} and name {} and resn {}".format(select[0][0], select[0][1], select[0][2])))
-    Atom_pair_2 = int(traj.topology.select("resSeq {} and name {} and resn {}".format(select[1][0], select[1][1], select[1][2])))
-    Atom_pair_3 = int(traj.topology.select("resSeq {} and name {} and resn {}".format(select[2][0], select[2][1], select[2][2])))
-    Atom_pair_4 = int(traj.topology.select("resSeq {} and name {} and resn {}".format(select[3][0], select[3][1], select[3][2])))
+    Atom_pair_1 = int(traj.topology.select(f"resSeq {select[0][0]} and name {select[0][1]} and resn {select[0][2]}"))
+    Atom_pair_2 = int(traj.topology.select(f"resSeq {select[1][0]} and name {select[1][1]} and resn {select[1][2]}"))
+    Atom_pair_3 = int(traj.topology.select(f"resSeq {select[2][0]} and name {select[2][1]} and resn {select[2][2]}"))
+    Atom_pair_4 = int(traj.topology.select(f"resSeq {select[3][0]} and name {select[3][1]} and resn {select[3][2]}"))
     metric_list = md.compute_dihedrals(traj, [[Atom_pair_1, Atom_pair_2, Atom_pair_3, Atom_pair_4]])
     metric_list = pd.Series(np.degrees(metric_list.flatten()))
     id = pd.Series([num for _ in range(len(metric_list))])
@@ -120,7 +118,7 @@ class SimulationRS:
             The number of cpus to extract the md trajectories
         """
         self.input_pdb = input_pdb
-        self.folder = folder
+        self.folder = Path(folder)
         self.dataframe = None
         self.profile = None
         self.catalytic = catalytic_dist
@@ -137,9 +135,9 @@ class SimulationRS:
         self.len = None
         self.dist_diff = None
         self.binding = None
-        self.name = basename(self.folder)
+        self.name = self.folder.name
         self.extract = extract
-        self.topology = "{}/input/{}_processed.pdb".format(dirname(dirname(folder)), basename(folder))
+        self.topology = self.folder.parent.parent/"input"/f"{self.folder.name}_processed.pdb"
         self.energy = energy
         self.res_dir = res_dir
         self.cpus = cpus
@@ -168,15 +166,14 @@ class SimulationRS:
         """
         Paralelizes the insert atomtype function
         """
-        if not os.path.exists("{}_RS/angles".format(self.res_dir)):
-            os.makedirs("{}_RS/angles".format(self.res_dir))
-        traject_list = sorted(glob("{}/trajectory_*".format(self.folder)), key=lambda s: int(basename(s)[:-4].split("_")[1]))
+        Path(f"{self.res_dir}_RS/angles").mkdir(parents=True, exist_ok=True)
+        traject_list = sorted(list(self.folder.glob("trajectory_*")), key=lambda s: int(s.stem.split("_")[1]))
         # parallelize the function
         p = Pool(self.cpus)
         func = partial(dihedral, select=select, topology=self.topology)
         angles = pd.concat(list(p.map(func, traject_list)))
         angles.reset_index(drop=True, inplace=True)
-        angles.to_csv("{}_RS/angles/{}.csv".format(self.res_dir, self.name), header=True)
+        angles.to_csv(f"{self.res_dir}_RS/angles/{self.name}.csv", header=True)
         return angles
 
     def filtering(self, follow=None):
@@ -190,9 +187,9 @@ class SimulationRS:
         select = self._transform_coordinates()
         angles = self.accelerated_dihedral(select)
         # read the reports
-        for files in sorted(glob("{}/report_*".format(self.folder)), key=lambda s: int(basename(s).split("_")[1])):
+        for files in sorted(self.folder.glob("report_*"), key=lambda s: int(s.name.split("_")[1])):
             residence_time = [0]
-            rep = int(basename(files).split("_")[1])
+            rep = int(files.name.split("_")[1])
             data = pd.read_csv(files, sep="    ", engine="python")
             data['#Task'].replace({1: rep}, inplace=True)
             data.rename(columns={'#Task': "ID"}, inplace=True)
@@ -232,26 +229,13 @@ class SimulationRS:
         type_ = []
         for x in self.profile["dihedral"].values:
             if -40 >= x >= -140:
-                type_.append("R_{}".format(self.name))
+                type_.append(f"R_{self.name}")
             elif 40 <= x <= 140:
-                type_.append("S_{}".format(self.name))
+                type_.append(f"S_{self.name}")
             else:
                 type_.append("noise")
         self.profile["Type"] = type_
 
-        # for the binning
-        type_2 = []
-        for x in frequency["dihedral"].values:
-            if -40 >= x >= -140:
-                type_2.append("R_{}".format(self.name))
-            elif 40 <= x <= 140:
-                type_2.append("S_{}".format(self.name))
-            else:
-                type_2.append("noise")
-        frequency["Type"] = type_2
-        self.all = pd.DataFrame(np.repeat(frequency[[self.followed, "Binding Energy", "residence time", "Type"]].values,
-                                          frequency["residence time"].values, axis=0),
-                                columns=[self.followed, "Binding Energy", "residence time", "Type"])
         # To extract the best distances
         trajectory = frequency.sort_values(by=self.followed)
         trajectory.reset_index(inplace=True)
@@ -268,100 +252,6 @@ class SimulationRS:
         self.trajectory["orientation"] = orien
 
 
-def match_dist(dihedral_atoms, input_pdb, wild):
-    """
-    match the user coordinates to pmx PDB coordinates
-    """
-    topology = "{}/input/{}_processed.pdb".format(dirname(dirname(wild)), basename(wild))
-    atom = dihedral_atoms[:]
-    for i in range(len(atom)):
-        atom[i] = map_atom_string(atom[i], input_pdb, topology)
-    return atom
-
-
-def binning(data_dict, res_dir, position_num, follow="distance0.5"):
-    """
-    Bins the values as to have a better analysis of the pele reports
-
-    Parameters
-    ___________
-    bin_dict: dict
-        A dictionary containing the mutations as keys and the SimulationData.all dataframe as values
-    res_dir: str
-        The directory for the results
-    position_num: str
-        The position at the which the mutations was produced
-    """
-    bin_dict = {}
-    for key, value in data_dict.items():
-        bin_dict[key] = value.all[["Binding Energy", follow, "Type"]].copy()
-    data = pd.concat(bin_dict.values())
-    energy_bin = np.linspace(min(data["Binding Energy"]), min(max(data["Binding Energy"]), min(data["Binding Energy"])+3), num=5)
-    distance_bin = np.linspace(min(data[follow]), min(max(data[follow]), min(data[follow])+3), num=5)
-    energybin_labels = ["({}, {}]".format(energy_bin[i], energy_bin[i + 1]) for i in range(len(energy_bin) - 1)]
-    distancebin_labels = ["({}, {}]".format(distance_bin[i], distance_bin[i + 1]) for i in range(len(distance_bin) - 1)]
-    # The best distance with different energies
-    best_distance = [data[(data["Binding Energy"].apply(lambda x: x in pd.Interval(energy_bin[i], energy_bin[i+1]))) &
-                     (data[follow].apply(lambda x: x in pd.Interval(distance_bin[0], distance_bin[1])))] for i in range(len(energy_bin)-1)]
-    # The best energies with different distances
-    best_energy = [data[(data["Binding Energy"].apply(lambda x: x in pd.Interval(energy_bin[0], energy_bin[1]))) &
-                   (data[follow].apply(lambda x: x in pd.Interval(distance_bin[i], distance_bin[i+1])))] for i in range(len(distance_bin)-1)]
-    # For bins in distance_active, I calculate the frequency and the median for each of the mutations and enantiomers
-    r_distance_len = [{key: len(frame[frame["Type"] == "R_{}".format(key)]) for key in bin_dict.keys()} for frame in best_distance]
-    r_distance_median = [{key: frame[frame["Type"] == "R_{}".format(key)][follow].median() for key in bin_dict.keys()} for frame in best_distance]
-    r_distance_energy = [{key: frame[frame["Type"] == "R_{}".format(key)]["Binding Energy"].median() for key in bin_dict.keys()} for frame in best_distance]
-    s_distance_len = [{key: len(frame[frame["Type"] == "S_{}".format(key)]) for key in bin_dict.keys()} for frame in best_distance]
-    s_distance_median = [{key: frame[frame["Type"] == "S_{}".format(key)][follow].median() for key in bin_dict.keys()} for frame in best_distance]
-    s_distance_energy = [
-        {key: frame[frame["Type"] == "S_{}".format(key)]["Binding Energy"].median() for key in bin_dict.keys()} for
-        frame in best_distance]
-    # For bins in energy active, I calculate the frequency, the median for each of the mutations and enantiomers
-    r_energy_len = [{key: len(frame[frame["Type"] == "R_{}".format(key)]) for key in bin_dict.keys()} for frame in best_energy]
-    r_energy_median = [{key: frame[frame["Type"] == "R_{}".format(key)]["Binding Energy"].median() for key in bin_dict.keys()} for frame in best_energy]
-    r_energy_distance = [
-        {key: frame[frame["Type"] == "R_{}".format(key)][follow].median() for key in bin_dict.keys()} for
-        frame in best_energy]
-    s_energy_len = [{key: len(frame[frame["Type"] == "S_{}".format(key)]) for key in bin_dict.keys()} for frame in best_energy]
-    s_energy_median = [{key: frame[frame["Type"] == "S_{}".format(key)]["Binding Energy"].median() for key in bin_dict.keys()} for frame in best_energy]
-    s_energy_distance = [
-        {key: frame[frame["Type"] == "S_{}".format(key)][follow].median() for key in bin_dict.keys()} for
-        frame in best_energy]
-    # For the energy bins, distance changes so using distance labels
-    r_energy_median = pd.DataFrame(r_energy_median, index=["R_{} energy median".format(x) for x in distancebin_labels])
-    s_energy_median = pd.DataFrame(s_energy_median, index=["S_{} energy median".format(x) for x in distancebin_labels])
-    r_energy_len = pd.DataFrame(r_energy_len, index=["R_{} energy freq".format(x) for x in distancebin_labels])
-    s_energy_len = pd.DataFrame(s_energy_len, index=["S_{} energy freq".format(x) for x in distancebin_labels])
-    r_energy_median.fillna(0, inplace=True)
-    s_energy_median.fillna(0, inplace=True)
-    r_energy_distance = pd.DataFrame(r_energy_distance, index=["R_{} energy distance median".format(x) for x in distancebin_labels])
-    s_energy_distance = pd.DataFrame(s_energy_distance, index=["S_{} energy distance median".format(x) for x in distancebin_labels])
-    r_energy_distance.fillna(0, inplace=True)
-    s_energy_distance.fillna(0, inplace=True)
-    # For the distance bins, energy changes so using energy labels
-    r_distance_median = pd.DataFrame(r_distance_median, index=["R_{} distance median".format(x) for x in energybin_labels])
-    s_distance_median = pd.DataFrame(s_distance_median, index=["S_{} distance median".format(x) for x in energybin_labels])
-    r_distance_median.fillna(0, inplace=True)
-    s_distance_median.fillna(0, inplace=True)
-    r_distance_len = pd.DataFrame(r_distance_len, index=["R_{} distance freq".format(x) for x in energybin_labels])
-    s_distance_len = pd.DataFrame(s_distance_len, index=["S_{} distance freq".format(x) for x in energybin_labels])
-    r_distance_energy = pd.DataFrame(r_distance_energy, index=["R_{} distance energy median".format(x) for x in energybin_labels])
-    s_distance_energy = pd.DataFrame(s_distance_energy, index=["S_{} distance energy median".format(x) for x in energybin_labels])
-    r_distance_energy.fillna(0, inplace=True)
-    s_distance_energy.fillna(0, inplace=True)
-    # concatenate everything
-    everything = pd.concat([r_energy_median, s_energy_median, r_energy_distance, s_energy_distance, r_energy_len,
-                            s_energy_len, r_distance_median, s_distance_median, r_distance_energy, s_distance_energy,
-                            r_distance_len, s_distance_len])
-    # To csv
-    if not os.path.exists("{}_RS/csv".format(res_dir)):
-        os.makedirs("{}_RS/csv".format(res_dir))
-    everything.to_csv("{}_RS/csv/binning_{}_{}.csv".format(res_dir, position_num, follow))
-    # save the dataframe with the reports in csvs
-    for key, value in data_dict.items():
-        value.dataframe.to_csv("{}_RS/csv/{}.csv".format(res_dir, key), header=True)
-    return everything
-
-
 def analyse_rs(folders, wild, dihedral_atoms, initial_pdb, res_dir, traj=5, cata_dist=3.5, extract=None, energy=None,
                cpus=10, follow="distance0.5"):
     """
@@ -399,14 +289,14 @@ def analyse_rs(folders, wild, dihedral_atoms, initial_pdb, res_dir, traj=5, cata
     """
     data_dict = {}
     atoms = match_dist(dihedral_atoms, initial_pdb, wild)
-    original = SimulationRS(wild, atoms, initial_pdb, res_dir,
-                            pdb=traj, catalytic_dist=cata_dist, extract=extract, energy=energy, cpus=cpus)
+    original = SimulationRS(wild, atoms, initial_pdb, res_dir, pdb=traj, catalytic_dist=cata_dist, extract=extract,
+                            energy=energy, cpus=cpus)
     original.filtering(follow)
     data_dict["original"] = original
     for folder in folders:
-        name = basename(folder)
-        data = SimulationRS(folder, atoms, initial_pdb, res_dir,
-                            pdb=traj, catalytic_dist=cata_dist, extract=extract, energy=energy, cpus=cpus)
+        name = Path(folder).name
+        data = SimulationRS(folder, atoms, initial_pdb, res_dir, pdb=traj, catalytic_dist=cata_dist, extract=extract,
+                            energy=energy, cpus=cpus)
         data.filtering(follow)
         data_dict[name] = data
 
@@ -441,20 +331,17 @@ def extract_snapshot_xtc_rs(res_dir, simulation_folder, f_id, position_num, muta
     follow: str, optional
         The column name of the different followed distances during PELE simulation
     """
-    if not os.path.exists("{}_RS/{}_{}/{}_pdbs".format(res_dir, follow, position_num, mutation)):
-        os.makedirs("{}_RS/{}_{}/{}_pdbs".format(res_dir, follow, position_num, mutation))
-
-    trajectories = glob("{}/*trajectory*_{}.*".format(simulation_folder, f_id))
-    topology = "{}/input/{}_processed.pdb".format(dirname(dirname(simulation_folder)), mutation)
-    if len(trajectories) == 0 or not os.path.exists(topology):
-        sys.exit("Trajectory_{} or topology file not found".format(f_id))
+    Path(f"{res_dir}_RS/{follow}_{position_num}/{mutation}_pdbs").mkdir(exist_ok=True, parents=True)
+    trajectories = list(Path(simulation_folder).glob(f"*trajectory*_{f_id}.*"))
+    topology = Path(simulation_folder).parent.parent/"input"/f"{mutation}_processed.pdb"
+    if len(trajectories) == 0 or not topology.exists():
+        sys.exit(f"Trajectory_{f_id} or topology file not found")
 
     # load the trajectory and write it to pdb
     traj = md.load_xtc(trajectories[0], topology)
-    name = "traj{}_step{}_dist{}_bind{}_{}_{}.pdb".format(f_id, step, round(dist, 2), round(bind, 2), orientation,
-                                                          round(angle, 2))
-    path_ = "{}_RS/{}_{}/{}_pdbs".format(res_dir, follow, position_num, mutation)
-    traj[int(step)].save_pdb(os.path.join(path_, name))
+    name = f"traj{f_id}_step{step}_dist{round(dist, 2)}_bind{round(bind, 2)}_{orientation}_{round(angle, 2)}.pdb"
+    path_ = Path(f"{res_dir}_RS/{follow}_{position_num}/{mutation}_pdbs")
+    traj[int(step)].save_pdb(path_/name)
 
 
 def snapshot_from_pdb_rs(res_dir, simulation_folder, f_id, position_num, mutation, step, dist, bind, orientation,
@@ -485,13 +372,11 @@ def snapshot_from_pdb_rs(res_dir, simulation_folder, f_id, position_num, mutatio
     follow: str, optional
         The column name of the different followed distances during PELE simulation
     """
-    if not os.path.exists("{}_RS/{}_{}/{}_pdbs".format(res_dir, follow, position_num, mutation)):
-        os.makedirs("{}_RS/{}_{}/{}_pdbs".format(res_dir, follow, position_num, mutation))
-
-    f_in = glob("{}/*trajectory*_{}.*".format(simulation_folder, f_id))
+    Path(f"{res_dir}_RS/{follow}_{position_num}/{mutation}_pdbs").mkdir(exist_ok=True, parents=True)
+    f_in = list(Path(simulation_folder).glob(f"*trajectory*_{f_id}.*"))
     if len(f_in) == 0:
-        sys.exit("Trajectory_{} not found. Be aware that PELE trajectories must contain the label 'trajectory' in "
-                 "their file name to be detected".format(f_id))
+        sys.exit(f"Trajectory_{f_id} not found. Be aware that PELE trajectories must contain the label 'trajectory' in "
+                 "their file name to be detected")
     f_in = f_in[0]
     with open(f_in, 'r') as res_dirfile:
         file_content = res_dirfile.read()
@@ -499,10 +384,9 @@ def snapshot_from_pdb_rs(res_dir, simulation_folder, f_id, position_num, mutatio
 
     # Output Snapshot
     traj = []
-    path_ = "{}_RS/{}_{}/{}_pdbs".format(res_dir, follow, position_num, mutation)
-    name = "traj{}_step{}_dist{}_bind{}_{}_{}.pdb".format(f_id, step, round(dist, 2), round(bind, 2), orientation,
-                                                          round(angle, 2))
-    with open(os.path.join(path_, name), 'w') as f:
+    path_ = Path(f"{res_dir}_RS/{follow}_{position_num}/{mutation}_pdbs")
+    name = f"traj{f_id}_step{step}_dist{round(dist, 2)}_bind{round(bind, 2)}_{orientation}_{round(angle, 2)}.pdb"
+    with open(path_/name, 'w') as f:
         traj.append("MODEL     {}".format(int(step) + 1))
         try:
             traj.append(trajectory_selected.group(1))
@@ -569,7 +453,7 @@ def extract_all(res_dir, data_dict, folders, cpus=10, xtc=False, follow="distanc
     """
     args = []
     for pele in folders:
-        name = basename(pele)
+        name = Path(pele).name
         output = name[:-1]
         args.append((pele, output, name))
 
@@ -605,8 +489,6 @@ def consecutive_analysis_rs(file_name, dihedral_atoms, initial_pdb, wild=None, d
        how many top pdbs are extracted from the trajectories
     plot_dir : str
        Name for the results folder
-    opt : str, optional
-       choose if to analyse distance, energy or both
     cpus : int, optional
        How many cpus to use to extract the top pdbs
     cata_dist: float, optional
@@ -620,32 +502,20 @@ def consecutive_analysis_rs(file_name, dihedral_atoms, initial_pdb, wild=None, d
     profile_with: str, optional
         The metric to generate the pele profiles with
     """
-    if os.path.exists("{}".format(file_name)):
-        folder, wild_ = find_log(file_name)
-        pele_folders = commonlist(folder)
-    else:
-        raise Exception("Pass a list of the path to the different folders")
-    if wild:
-        wild_ = wild
-    if not plot_dir:
-        plot_dir = commonprefix(pele_folders[0])
-        plot_dir = list(filter(lambda x: "_mut" in x, plot_dir.split("/")))
-        plot_dir = plot_dir[0].replace("_mut", "")
+    pele_folders, plot_dir, wild = check_completed_log(file_name, wild, plot_dir)
     for folders in pele_folders:
-        base = basename(folders[0])[:-1]
-        data_dict = analyse_rs(folders, wild_, dihedral_atoms, initial_pdb, plot_dir, traj, cata_dist, extract,
-                               energy, cpus)
-        binning(data_dict, plot_dir, base)
+        base = Path(folders[0]).name[:-1]
+        data_dict = analyse_rs(folders, wild, dihedral_atoms, initial_pdb, plot_dir, traj, cata_dist, extract, energy, cpus)
         all_profiles(plot_dir, data_dict, base, dpi, mode="RS", profile_with=profile_with)
         extract_all(plot_dir, data_dict, folders, cpus, xtc=xtc)
 
 
 def main():
-    inp, dpi, traj, folder, cpus, cata_dist, xtc,  extract, dihedral_atoms, energy, initial_pdb, profile_with, \
-    wild = parse_args()
-    consecutive_analysis_rs(inp, dihedral_atoms, initial_pdb, wild, dpi=dpi, traj=traj, plot_dir=folder,
-                            cpus=cpus, cata_dist=cata_dist, xtc=xtc, extract=extract,
-                            energy=energy, profile_with=profile_with)
+    simulation_folder, dpi, traj, folder, cpus, cata_dist, xtc,  extract, dihedral_atoms, energy, initial_pdb, \
+    profile_with, wild = parse_args()
+    consecutive_analysis_rs(simulation_folder, dihedral_atoms, initial_pdb, wild, dpi=dpi, traj=traj, plot_dir=folder,
+                            cpus=cpus, cata_dist=cata_dist, xtc=xtc, extract=extract, energy=energy,
+                            profile_with=profile_with)
 
 
 if __name__ == "__main__":
